# skyfire-sdk
The Skyfire SDK is designed to allow agents to interact with the Skyfire platform to enable autonomous payments.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 0.6.11
- Generator version: 7.7.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import skyfire_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import skyfire_sdk
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import skyfire_sdk
from skyfire_sdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost:3000
# See configuration.py for a list of all supported configuration parameters.
configuration = skyfire_sdk.Configuration(
    host = "http://localhost:3000"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKeyAuth
configuration.api_key['ApiKeyAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKeyAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with skyfire_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = skyfire_sdk.APINinjaApi(api_client)
    symbol = 'LTCBTC' # str | Cryptocurrency symbol.

    try:
        # Crypto Price
        api_response = api_instance.crypto_price(symbol)
        print("The response of APINinjaApi->crypto_price:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling APINinjaApi->crypto_price: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:3000*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*APINinjaApi* | [**crypto_price**](docs/APINinjaApi.md#crypto_price) | **GET** /proxy/api-ninja/v1/cryptoprice | Crypto Price
*APINinjaApi* | [**dns_lookup**](docs/APINinjaApi.md#dns_lookup) | **GET** /proxy/api-ninja/v1/dnslookup | DNS Lookup
*APINinjaApi* | [**ip_lookup**](docs/APINinjaApi.md#ip_lookup) | **GET** /proxy/api-ninja/v1/iplookup | IP Lookup
*APINinjaApi* | [**stock_price**](docs/APINinjaApi.md#stock_price) | **GET** /proxy/api-ninja/v1/stockprice | Stock Price
*APINinjaApi* | [**weather**](docs/APINinjaApi.md#weather) | **GET** /proxy/api-ninja/v1/weather | Weather
*EmailApi* | [**send_email**](docs/EmailApi.md#send_email) | **POST** /v1/receivers/toolkit/send-email | Send Email
*GiftCardApi* | [**countries**](docs/GiftCardApi.md#countries) | **GET** /v1/receivers/reloadly/countries | Get Countries
*GiftCardApi* | [**get_redeem_code**](docs/GiftCardApi.md#get_redeem_code) | **GET** /v1/receivers/reloadly/redeem-code/{orderId} | Get Product Info By Brand
*GiftCardApi* | [**gift_card_order**](docs/GiftCardApi.md#gift_card_order) | **POST** /v1/receivers/reloadly/gift-card | Send Gift Card
*GiftCardApi* | [**product_info**](docs/GiftCardApi.md#product_info) | **GET** /v1/receivers/reloadly/product-info/{brand} | Get Product Info By Brand
*GiftCardApi* | [**product_info_by_country_code**](docs/GiftCardApi.md#product_info_by_country_code) | **GET** /v1/receivers/reloadly/product-info/country/{countryCode} | Get Product Info by Country Code
*NetNutApi* | [**proxy_net_nut_request**](docs/NetNutApi.md#proxy_net_nut_request) | **POST** /v1/receivers/netnut | Proxy
*OpenAIApi* | [**create_open_ai_chat_completion**](docs/OpenAIApi.md#create_open_ai_chat_completion) | **POST** /proxy/openai/v1/chat/completions | Creates a model response for the given chat conversation.
*OpenRouterApi* | [**create_open_router_chat_completion**](docs/OpenRouterApi.md#create_open_router_chat_completion) | **POST** /proxy/openrouter/v1/chat/completions | Creates a model response for the given chat conversation.
*OrganizationApi* | [**create_organization**](docs/OrganizationApi.md#create_organization) | **POST** /v1/enterprise/admin/organizations | Create Organization
*OrganizationApi* | [**create_organization_user**](docs/OrganizationApi.md#create_organization_user) | **POST** /v1/enterprise/admin/users/organizationUser | Create User
*OrganizationApi* | [**create_primary_eth_wallet**](docs/OrganizationApi.md#create_primary_eth_wallet) | **POST** /v1/enterprise/admin/organizations/wallet | Create Wallet
*OrganizationApi* | [**delete_organization**](docs/OrganizationApi.md#delete_organization) | **DELETE** /v1/enterprise/admin/organizations/id/{id} | Delete Organization By ID
*OrganizationApi* | [**delete_organization_by_name**](docs/OrganizationApi.md#delete_organization_by_name) | **DELETE** /v1/enterprise/admin/organizations/name/{name} | Delete Organization By Name
*OrganizationApi* | [**delete_wallet_endpoint**](docs/OrganizationApi.md#delete_wallet_endpoint) | **DELETE** /v1/enterprise/admin/organizations/wallet/id/{walletId} | Delete Wallet
*OrganizationApi* | [**enterprise_admin_create_bridge_virtual_account**](docs/OrganizationApi.md#enterprise_admin_create_bridge_virtual_account) | **POST** /v1/enterprise/admin/bridge/virtual-accounts | Create ACH Account
*OrganizationApi* | [**enterprise_admin_deactivate_bridge_virtual_account**](docs/OrganizationApi.md#enterprise_admin_deactivate_bridge_virtual_account) | **POST** /v1/enterprise/admin/bridge/virtual-accounts/deactivate | Deactivate ACH Account
*OrganizationApi* | [**enterprise_admin_reactivate_bridge_virtual_account**](docs/OrganizationApi.md#enterprise_admin_reactivate_bridge_virtual_account) | **POST** /v1/enterprise/admin/bridge/virtual-accounts/reactivate | Reactivate ACH Account
*OrganizationApi* | [**enterprise_delete_api_key_for_user**](docs/OrganizationApi.md#enterprise_delete_api_key_for_user) | **DELETE** /v1/enterprise/admin/users/api-keys/{uuid} | Delete API Key
*OrganizationApi* | [**enterprise_generate_api_key_for_user**](docs/OrganizationApi.md#enterprise_generate_api_key_for_user) | **POST** /v1/enterprise/admin/users/api-keys | Create API Key
*OrganizationApi* | [**enterprise_get_api_key_for_user**](docs/OrganizationApi.md#enterprise_get_api_key_for_user) | **GET** /v1/enterprise/admin/users/api-keys/{email} | Get All API Keys
*OrganizationApi* | [**get_claims_for_user_enterprise**](docs/OrganizationApi.md#get_claims_for_user_enterprise) | **GET** /v1/enterprise/admin/wallet/claims/{email} | Claims
*OrganizationApi* | [**get_organization_user**](docs/OrganizationApi.md#get_organization_user) | **GET** /v1/enterprise/admin/users/organizationUser/{email} | Get User
*OrganizationApi* | [**get_organization_users**](docs/OrganizationApi.md#get_organization_users) | **GET** /v1/enterprise/admin/organizations/id/{id} | Get Organization By ID
*OrganizationApi* | [**get_organization_users_by_id**](docs/OrganizationApi.md#get_organization_users_by_id) | **GET** /v1/enterprise/admin/organizations/list/id/{id} | Get Users by Org ID
*OrganizationApi* | [**get_organization_users_by_name**](docs/OrganizationApi.md#get_organization_users_by_name) | **GET** /v1/enterprise/admin/organizations/list/{name} | Get Users by Org Name
*OrganizationApi* | [**get_organizations**](docs/OrganizationApi.md#get_organizations) | **GET** /v1/enterprise/admin/organizations | Get Organizations
*OrganizationApi* | [**get_redemptions_for_user_enterprise**](docs/OrganizationApi.md#get_redemptions_for_user_enterprise) | **GET** /v1/enterprise/admin/wallet/redemptions/{email} | Redemptions
*OrganizationApi* | [**get_transactions_for_user_enterprise**](docs/OrganizationApi.md#get_transactions_for_user_enterprise) | **GET** /v1/enterprise/admin/wallet/transactions/{email} | Transactions
*OrganizationApi* | [**get_wallet_balance_for_user_enterprise**](docs/OrganizationApi.md#get_wallet_balance_for_user_enterprise) | **GET** /v1/enterprise/admin/organizations/wallet/balance/{email} | Wallet Balance
*OrganizationApi* | [**get_wallet_balances_for_organization_enterprise**](docs/OrganizationApi.md#get_wallet_balances_for_organization_enterprise) | **GET** /v1/enterprise/admin/organizations/balances/name/{name} | Wallet Balance
*OrganizationApi* | [**move_user**](docs/OrganizationApi.md#move_user) | **POST** /v1/enterprise/admin/users/organizationUser/move | Move User
*OrganizationApi* | [**switch_default_by_wallet_id_endpoint**](docs/OrganizationApi.md#switch_default_by_wallet_id_endpoint) | **GET** /v1/enterprise/admin/organizations/switch-default-wallet/id/{walletId} | Switch Default Wallet
*OrganizationApi* | [**validate_group_payment**](docs/OrganizationApi.md#validate_group_payment) | **GET** /v1/enterprise/admin/payments/validate | Validate Payment
*PaymentsApi* | [**claim_group_by_group_id**](docs/PaymentsApi.md#claim_group_by_group_id) | **GET** /v1/payment/claimGroupByGroupId/{groupId} | ClaimGroup by GroupId
*PaymentsApi* | [**execute_payment_standalone**](docs/PaymentsApi.md#execute_payment_standalone) | **GET** /v1/payment/execute-payment/{groupId} | Execute Payment
*PaymentsApi* | [**hold_payment_standalone**](docs/PaymentsApi.md#hold_payment_standalone) | **POST** /v1/payment/hold-payment | Hold Payment
*PaymentsApi* | [**make_payment_standalone**](docs/PaymentsApi.md#make_payment_standalone) | **POST** /v1/payment | Standalone Payment
*PaymentsApi* | [**make_payment_standalone_by_url**](docs/PaymentsApi.md#make_payment_standalone_by_url) | **POST** /v1/payment/url | Standalone Payment from URL
*PaymentsApi* | [**make_payment_standalone_via_tool**](docs/PaymentsApi.md#make_payment_standalone_via_tool) | **POST** /v1/payment/tool | Standalone Payment
*PerplexityApi* | [**create_perplexity_chat_completion**](docs/PerplexityApi.md#create_perplexity_chat_completion) | **POST** /proxy/perplexity/chat/completions | Creates a model response for the given chat conversation.
*PricingCultureApi* | [**dailycomps**](docs/PricingCultureApi.md#dailycomps) | **GET** /proxy/pricing-culture/api/data/dailycomps | Luxury Daily Comps
*PricingCultureApi* | [**snapshot**](docs/PricingCultureApi.md#snapshot) | **GET** /proxy/pricing-culture/api/data/dailycomps/snapshot | Luxury Daily Comps Snapshot
*VeniceApi* | [**create_venice_chat_completion**](docs/VeniceApi.md#create_venice_chat_completion) | **POST** /proxy/venice-ai/api/v1/chat/completions | Using Venice: Creates a model response for the given chat conversation.
*VetricApi* | [**facebook_event_search**](docs/VetricApi.md#facebook_event_search) | **POST** /proxy/vetric-facebook/facebook/v1/search/events | Facebook Event Search (Proxy)
*VetricApi* | [**facebook_user_search**](docs/VetricApi.md#facebook_user_search) | **POST** /proxy/vetric-facebook/facebook/v1/search/users | Facebook People Search (Proxy)
*VetricApi* | [**instagram_location_map**](docs/VetricApi.md#instagram_location_map) | **GET** /proxy/vetric-instagram/instagram/v1/locations/map | Instagram Location Map (Proxy)
*VetricApi* | [**instagram_user_search**](docs/VetricApi.md#instagram_user_search) | **GET** /proxy/vetric-instagram/instagram/v1/users/search | Instagram People Search (Proxy)
*VetricApi* | [**linked_in_company_employees**](docs/VetricApi.md#linked_in_company_employees) | **GET** /proxy/vetric-linkedin/linkedin/v1/company/{identifier}/people | LinkedIn Employee Search (Proxy)
*VetricApi* | [**linked_in_job_search**](docs/VetricApi.md#linked_in_job_search) | **GET** /proxy/vetric-linkedin/linkedin/v1/search/jobs | LinkedIn Job Search (Proxy)
*VetricApi* | [**linked_in_people_search**](docs/VetricApi.md#linked_in_people_search) | **GET** /proxy/vetric-linkedin/linkedin/v1/search/people | LinkedIn People Search (Proxy)
*VetricApi* | [**marketplace_search**](docs/VetricApi.md#marketplace_search) | **POST** /proxy/vetric-facebook/facebook/v1/marketplace/search | Facebook Marketplace Search (Proxy)
*VetricApi* | [**top_search_results**](docs/VetricApi.md#top_search_results) | **GET** /proxy/vetric-twitter/twitter/v1/search/top | Twitter Top Tweets (Proxy)
*WalletManagementApi* | [**claims_by_group_id**](docs/WalletManagementApi.md#claims_by_group_id) | **GET** /v1/wallet/claimsByGroupId/{groupId} | ClaimGroup by GroupId
*WalletManagementApi* | [**delete_wallet**](docs/WalletManagementApi.md#delete_wallet) | **GET** /v1/wallet/delete/{walletId} | Delete Wallet
*WalletManagementApi* | [**get_claim_by_reference_id**](docs/WalletManagementApi.md#get_claim_by_reference_id) | **GET** /v1/wallet/claimByReferenceId/{referenceId} | Claim by ReferenceId
*WalletManagementApi* | [**get_claims_for_user**](docs/WalletManagementApi.md#get_claims_for_user) | **GET** /v1/wallet/claims | Claims
*WalletManagementApi* | [**get_organization_wallets**](docs/WalletManagementApi.md#get_organization_wallets) | **GET** /v1/wallet/organizations | Organization Wallets
*WalletManagementApi* | [**get_wallet_balance_by_address**](docs/WalletManagementApi.md#get_wallet_balance_by_address) | **GET** /v1/wallet/balance/{network} | Balance by Network
*WalletManagementApi* | [**get_wallet_balance_for_user**](docs/WalletManagementApi.md#get_wallet_balance_for_user) | **GET** /v1/wallet/balance | Wallet Balance
*WalletManagementApi* | [**wallet**](docs/WalletManagementApi.md#wallet) | **GET** /v1/wallet | Wallet


## Documentation For Models

 - [APINinjaCryptoPriceResponse](docs/APINinjaCryptoPriceResponse.md)
 - [APINinjaDNSLookupResponse](docs/APINinjaDNSLookupResponse.md)
 - [APINinjaDNSRecord](docs/APINinjaDNSRecord.md)
 - [APINinjaIPLookupResponse](docs/APINinjaIPLookupResponse.md)
 - [APINinjaStockResponse](docs/APINinjaStockResponse.md)
 - [APINinjaWeatherResponse](docs/APINinjaWeatherResponse.md)
 - [BridgeDestination](docs/BridgeDestination.md)
 - [BridgeSourceDepositAddress](docs/BridgeSourceDepositAddress.md)
 - [BridgeVirtualAccount](docs/BridgeVirtualAccount.md)
 - [ChatCompletionMessageToolCall](docs/ChatCompletionMessageToolCall.md)
 - [ChatCompletionMessageToolCallFunction](docs/ChatCompletionMessageToolCallFunction.md)
 - [ChatCompletionRequestMessage](docs/ChatCompletionRequestMessage.md)
 - [ChatCompletionResponseMessage](docs/ChatCompletionResponseMessage.md)
 - [ChatCompletionResponseMessageFunctionCall](docs/ChatCompletionResponseMessageFunctionCall.md)
 - [ChatCompletionStreamOptions](docs/ChatCompletionStreamOptions.md)
 - [ChatCompletionTokenLogprob](docs/ChatCompletionTokenLogprob.md)
 - [ChatCompletionTokenLogprobTopLogprobsInner](docs/ChatCompletionTokenLogprobTopLogprobsInner.md)
 - [ChatCompletionTool](docs/ChatCompletionTool.md)
 - [Claim](docs/Claim.md)
 - [ClaimGroup](docs/ClaimGroup.md)
 - [ClaimsResponse](docs/ClaimsResponse.md)
 - [CompletionUsage](docs/CompletionUsage.md)
 - [CreateApiKey](docs/CreateApiKey.md)
 - [CreateChatCompletionRequest](docs/CreateChatCompletionRequest.md)
 - [CreateChatCompletionRequestResponseFormat](docs/CreateChatCompletionRequestResponseFormat.md)
 - [CreateChatCompletionResponse](docs/CreateChatCompletionResponse.md)
 - [CreateChatCompletionResponseChoicesInner](docs/CreateChatCompletionResponseChoicesInner.md)
 - [CreateChatCompletionResponseChoicesInnerLogprobs](docs/CreateChatCompletionResponseChoicesInnerLogprobs.md)
 - [CreateOrganization200Response](docs/CreateOrganization200Response.md)
 - [CreateOrganizationRequest](docs/CreateOrganizationRequest.md)
 - [CreatePrimaryEthWalletRequest](docs/CreatePrimaryEthWalletRequest.md)
 - [CreateUserFromEnterpriseAdminParams](docs/CreateUserFromEnterpriseAdminParams.md)
 - [CustodyProvider](docs/CustodyProvider.md)
 - [EmailDumpRequest](docs/EmailDumpRequest.md)
 - [EnterpriseAdminCreateBridgeVirtualAccountRequest](docs/EnterpriseAdminCreateBridgeVirtualAccountRequest.md)
 - [EnterpriseGenerateApiKeyForUserRequest](docs/EnterpriseGenerateApiKeyForUserRequest.md)
 - [ErrorCode](docs/ErrorCode.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [EthNetworkType](docs/EthNetworkType.md)
 - [Fees](docs/Fees.md)
 - [FunctionObject](docs/FunctionObject.md)
 - [GetApiKeys](docs/GetApiKeys.md)
 - [IdentityCheckType](docs/IdentityCheckType.md)
 - [MakePaymentStandaloneByUrlRequest](docs/MakePaymentStandaloneByUrlRequest.md)
 - [MoveUserFromEnterpriseAdminParams](docs/MoveUserFromEnterpriseAdminParams.md)
 - [NetNutResponse](docs/NetNutResponse.md)
 - [OpenRouterCreateChatCompletionRequest](docs/OpenRouterCreateChatCompletionRequest.md)
 - [Organization](docs/Organization.md)
 - [OrganizationResponse](docs/OrganizationResponse.md)
 - [OrganizationResponseWithUsersAndWallets](docs/OrganizationResponseWithUsersAndWallets.md)
 - [PaginationMeta](docs/PaginationMeta.md)
 - [PerplexityCreateChatCompletionRequest](docs/PerplexityCreateChatCompletionRequest.md)
 - [PricingCultureCompAttributes](docs/PricingCultureCompAttributes.md)
 - [PricingCultureCompParams](docs/PricingCultureCompParams.md)
 - [PricingCultureCompResponse](docs/PricingCultureCompResponse.md)
 - [PricingCultureObject](docs/PricingCultureObject.md)
 - [PricingCultureSnapshotAssetDetails](docs/PricingCultureSnapshotAssetDetails.md)
 - [PricingCultureSnapshotObject](docs/PricingCultureSnapshotObject.md)
 - [PricingCultureSnapshotResponse](docs/PricingCultureSnapshotResponse.md)
 - [ProxyNetNutRequestRequest](docs/ProxyNetNutRequestRequest.md)
 - [Receiver](docs/Receiver.md)
 - [ReceiverUserResponse](docs/ReceiverUserResponse.md)
 - [Redemption](docs/Redemption.md)
 - [RedemptionSummary](docs/RedemptionSummary.md)
 - [RedemptionsResponse](docs/RedemptionsResponse.md)
 - [ReloadlyControllerResponse](docs/ReloadlyControllerResponse.md)
 - [ReloadlyControllerResponseOrder](docs/ReloadlyControllerResponseOrder.md)
 - [ReloadlyCountry](docs/ReloadlyCountry.md)
 - [ReloadlyGiftCardAPIRequestParams](docs/ReloadlyGiftCardAPIRequestParams.md)
 - [ReloadlyGiftCardAPIRequestParamsSendEmail](docs/ReloadlyGiftCardAPIRequestParamsSendEmail.md)
 - [ReloadlyProductsResponseItem](docs/ReloadlyProductsResponseItem.md)
 - [ReloadlyProductsResponseItemBrand](docs/ReloadlyProductsResponseItemBrand.md)
 - [ReloadlyProductsResponseItemCategory](docs/ReloadlyProductsResponseItemCategory.md)
 - [ReloadlyProductsResponseItemCountry](docs/ReloadlyProductsResponseItemCountry.md)
 - [ReloadlyProductsResponseItemRedeemInstruction](docs/ReloadlyProductsResponseItemRedeemInstruction.md)
 - [ReloadlyRedeemCodeRespose](docs/ReloadlyRedeemCodeRespose.md)
 - [ReloadlyRedeemInstructionsResponse](docs/ReloadlyRedeemInstructionsResponse.md)
 - [RuleFrequency](docs/RuleFrequency.md)
 - [RuleType](docs/RuleType.md)
 - [SkyfireUser](docs/SkyfireUser.md)
 - [SkyfireUserResponse](docs/SkyfireUserResponse.md)
 - [StandalonePaymentRequest](docs/StandalonePaymentRequest.md)
 - [StandalonePaymentRequestItem](docs/StandalonePaymentRequestItem.md)
 - [StandalonePaymentRequestViaTool](docs/StandalonePaymentRequestViaTool.md)
 - [StandalonePaymentResponse](docs/StandalonePaymentResponse.md)
 - [Transaction](docs/Transaction.md)
 - [TransactionsResponse](docs/TransactionsResponse.md)
 - [UserOrganization](docs/UserOrganization.md)
 - [UserRule](docs/UserRule.md)
 - [UserType](docs/UserType.md)
 - [VeniceCreateChatCompletionRequest](docs/VeniceCreateChatCompletionRequest.md)
 - [VeniceCreateChatCompletionRequestMessagesInner](docs/VeniceCreateChatCompletionRequestMessagesInner.md)
 - [VeniceCreateChatCompletionResponse](docs/VeniceCreateChatCompletionResponse.md)
 - [VeniceCreateChatCompletionResponseChoicesInner](docs/VeniceCreateChatCompletionResponseChoicesInner.md)
 - [VetricFacebookEventSearchResponse](docs/VetricFacebookEventSearchResponse.md)
 - [VetricFacebookEventSearchResponseSearchQuery](docs/VetricFacebookEventSearchResponseSearchQuery.md)
 - [VetricFacebookEventSearchResponseSearchQueryCombinedResults](docs/VetricFacebookEventSearchResponseSearchQueryCombinedResults.md)
 - [VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInner](docs/VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInner.md)
 - [VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateView](docs/VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateView.md)
 - [VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInner](docs/VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInner.md)
 - [VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInner](docs/VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInner.md)
 - [VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInnerEvent](docs/VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInnerEvent.md)
 - [VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInnerEventEventPlace](docs/VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInnerEventEventPlace.md)
 - [VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInnerEventEventProfilePicture](docs/VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInnerEventEventProfilePicture.md)
 - [VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInnerEventFeaturableImage](docs/VetricFacebookEventSearchResponseSearchQueryCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInnerEventFeaturableImage.md)
 - [VetricFacebookEventSearchResponseSearchQueryCombinedResultsPageInfo](docs/VetricFacebookEventSearchResponseSearchQueryCombinedResultsPageInfo.md)
 - [VetricFacebookEventSearchResponseSearchQueryFilterTypeSetsInner](docs/VetricFacebookEventSearchResponseSearchQueryFilterTypeSetsInner.md)
 - [VetricFacebookEventSearchResponseSearchQueryFilterTypeSetsInnerFiltersInner](docs/VetricFacebookEventSearchResponseSearchQueryFilterTypeSetsInnerFiltersInner.md)
 - [VetricFacebookEventSearchResponseSearchQueryFilterTypeSetsInnerFiltersInnerMainFilter](docs/VetricFacebookEventSearchResponseSearchQueryFilterTypeSetsInnerFiltersInnerMainFilter.md)
 - [VetricFacebookEventSearchResponseSearchQueryFilterTypeSetsInnerFiltersInnerMainFilterFilterValues](docs/VetricFacebookEventSearchResponseSearchQueryFilterTypeSetsInnerFiltersInnerMainFilterFilterValues.md)
 - [VetricFacebookEventSearchResponseSearchQueryFilterTypeSetsInnerFiltersInnerMainFilterFilterValuesEdgesInner](docs/VetricFacebookEventSearchResponseSearchQueryFilterTypeSetsInnerFiltersInnerMainFilterFilterValuesEdgesInner.md)
 - [VetricFacebookEventSearchResponseSearchQueryFilterTypeSetsInnerFiltersInnerMainFilterFilterValuesEdgesInnerNode](docs/VetricFacebookEventSearchResponseSearchQueryFilterTypeSetsInnerFiltersInnerMainFilterFilterValuesEdgesInnerNode.md)
 - [VetricFacebookUserSearchResponse](docs/VetricFacebookUserSearchResponse.md)
 - [VetricFacebookUserSearchResponseCombinedResults](docs/VetricFacebookUserSearchResponseCombinedResults.md)
 - [VetricFacebookUserSearchResponseCombinedResultsEdgesInner](docs/VetricFacebookUserSearchResponseCombinedResultsEdgesInner.md)
 - [VetricFacebookUserSearchResponseCombinedResultsEdgesInnerNativeTemplateView](docs/VetricFacebookUserSearchResponseCombinedResultsEdgesInnerNativeTemplateView.md)
 - [VetricFacebookUserSearchResponseCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInner](docs/VetricFacebookUserSearchResponseCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInner.md)
 - [VetricFacebookUserSearchResponseCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInner](docs/VetricFacebookUserSearchResponseCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInner.md)
 - [VetricFacebookUserSearchResponseCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInnerRecentSearchEntityValue](docs/VetricFacebookUserSearchResponseCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInnerRecentSearchEntityValue.md)
 - [VetricFacebookUserSearchResponseCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInnerRecentSearchEntityValueProfilePicture](docs/VetricFacebookUserSearchResponseCombinedResultsEdgesInnerNativeTemplateViewNativeTemplateBundlesInnerNtBundleAttributesInnerRecentSearchEntityValueProfilePicture.md)
 - [VetricFacebookUserSearchResponseCombinedResultsPageInfo](docs/VetricFacebookUserSearchResponseCombinedResultsPageInfo.md)
 - [VetricFacebookUserSearchResponseFilterTypeSetsInner](docs/VetricFacebookUserSearchResponseFilterTypeSetsInner.md)
 - [VetricFacebookUserSearchResponseFilterTypeSetsInnerFiltersInner](docs/VetricFacebookUserSearchResponseFilterTypeSetsInnerFiltersInner.md)
 - [VetricFacebookUserSearchResponseFilterTypeSetsInnerFiltersInnerMainFilter](docs/VetricFacebookUserSearchResponseFilterTypeSetsInnerFiltersInnerMainFilter.md)
 - [VetricFacebookUserSearchResponseFilterTypeSetsInnerFiltersInnerMainFilterFilterValues](docs/VetricFacebookUserSearchResponseFilterTypeSetsInnerFiltersInnerMainFilterFilterValues.md)
 - [VetricFacebookUserSearchResponseFilterTypeSetsInnerFiltersInnerMainFilterFilterValuesEdgesInner](docs/VetricFacebookUserSearchResponseFilterTypeSetsInnerFiltersInnerMainFilterFilterValuesEdgesInner.md)
 - [VetricInstagramLocationMapResponse](docs/VetricInstagramLocationMapResponse.md)
 - [VetricInstagramLocationMapResponsePinsInner](docs/VetricInstagramLocationMapResponsePinsInner.md)
 - [VetricInstagramLocationMapResponsePinsInnerLocation](docs/VetricInstagramLocationMapResponsePinsInnerLocation.md)
 - [VetricInstagramLocationMapResponsePinsInnerPageInfo](docs/VetricInstagramLocationMapResponsePinsInnerPageInfo.md)
 - [VetricInstagramLocationMapResponsePinsInnerPageInfoHours](docs/VetricInstagramLocationMapResponsePinsInnerPageInfoHours.md)
 - [VetricInstagramLocationMapResponsePinsInnerPageInfoHoursScheduleInner](docs/VetricInstagramLocationMapResponsePinsInnerPageInfoHoursScheduleInner.md)
 - [VetricInstagramLocationMapResponsePinsInnerPageInfoPageEffectInfo](docs/VetricInstagramLocationMapResponsePinsInnerPageInfoPageEffectInfo.md)
 - [VetricInstagramLocationMapResponsePinsInnerPreviewMediasInner](docs/VetricInstagramLocationMapResponsePinsInnerPreviewMediasInner.md)
 - [VetricInstagramUserSearchResponse](docs/VetricInstagramUserSearchResponse.md)
 - [VetricInstagramUserSearchResponseUsersInner](docs/VetricInstagramUserSearchResponseUsersInner.md)
 - [VetricInstagramUserSearchResponseUsersInnerFriendshipStatus](docs/VetricInstagramUserSearchResponseUsersInnerFriendshipStatus.md)
 - [VetricLinkedInCompanyPeopleResponse](docs/VetricLinkedInCompanyPeopleResponse.md)
 - [VetricLinkedInCompanyPeopleResponsePeopleInner](docs/VetricLinkedInCompanyPeopleResponsePeopleInner.md)
 - [VetricLinkedInJobSearchResponse](docs/VetricLinkedInJobSearchResponse.md)
 - [VetricLinkedInJobSearchResponseJobsInner](docs/VetricLinkedInJobSearchResponseJobsInner.md)
 - [VetricLinkedInPeopleSearchResponse](docs/VetricLinkedInPeopleSearchResponse.md)
 - [VetricLinkedInPeopleSearchResponsePeopleInner](docs/VetricLinkedInPeopleSearchResponsePeopleInner.md)
 - [VetricMarketplaceSearchResponse](docs/VetricMarketplaceSearchResponse.md)
 - [VetricMarketplaceSearchResponseData](docs/VetricMarketplaceSearchResponseData.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearch](docs/VetricMarketplaceSearchResponseDataMarketplaceSearch.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnits](docs/VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnits.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInner](docs/VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInner.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNode](docs/VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNode.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodeData](docs/VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodeData.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodeDataPrice](docs/VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodeDataPrice.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodePhoto](docs/VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodePhoto.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodePhotoDefaultImage](docs/VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodePhotoDefaultImage.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodePhotoSmartResizedImage](docs/VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodePhotoSmartResizedImage.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodeRow1](docs/VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodeRow1.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodeRow1CurrentPriceAmount](docs/VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodeRow1CurrentPriceAmount.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodeRow2](docs/VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodeRow2.md)
 - [VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodeRow3](docs/VetricMarketplaceSearchResponseDataMarketplaceSearchFeedUnitsEdgesInnerNodeRow3.md)
 - [VetricTwitterTopSearchResponse](docs/VetricTwitterTopSearchResponse.md)
 - [VetricTwitterTopSearchResponseTweetsInner](docs/VetricTwitterTopSearchResponseTweetsInner.md)
 - [VetricTwitterTopSearchResponseTweetsInnerTweet](docs/VetricTwitterTopSearchResponseTweetsInnerTweet.md)
 - [VetricTwitterTopSearchResponseTweetsInnerTweetEntities](docs/VetricTwitterTopSearchResponseTweetsInnerTweetEntities.md)
 - [VetricTwitterTopSearchResponseTweetsInnerTweetExtendedEntities](docs/VetricTwitterTopSearchResponseTweetsInnerTweetExtendedEntities.md)
 - [VetricTwitterTopSearchResponseTweetsInnerTweetExtendedEntitiesMediaInner](docs/VetricTwitterTopSearchResponseTweetsInnerTweetExtendedEntitiesMediaInner.md)
 - [VetricTwitterTopSearchResponseTweetsInnerTweetExtendedEntitiesMediaInnerExtMediaStats](docs/VetricTwitterTopSearchResponseTweetsInnerTweetExtendedEntitiesMediaInnerExtMediaStats.md)
 - [VetricTwitterTopSearchResponseTweetsInnerTweetExtendedEntitiesMediaInnerOriginalInfo](docs/VetricTwitterTopSearchResponseTweetsInnerTweetExtendedEntitiesMediaInnerOriginalInfo.md)
 - [VetricTwitterTopSearchResponseTweetsInnerTweetExtendedEntitiesMediaInnerVideoInfo](docs/VetricTwitterTopSearchResponseTweetsInnerTweetExtendedEntitiesMediaInnerVideoInfo.md)
 - [VetricTwitterTopSearchResponseTweetsInnerTweetExtendedEntitiesMediaInnerVideoInfoVariantsInner](docs/VetricTwitterTopSearchResponseTweetsInnerTweetExtendedEntitiesMediaInnerVideoInfoVariantsInner.md)
 - [VetricTwitterTopSearchResponseTweetsInnerTweetUserDetails](docs/VetricTwitterTopSearchResponseTweetsInnerTweetUserDetails.md)
 - [VetricTwitterTopSearchResponseTweetsInnerTweetUserDetailsEntities](docs/VetricTwitterTopSearchResponseTweetsInnerTweetUserDetailsEntities.md)
 - [VetricTwitterTopSearchResponseTweetsInnerTweetUserDetailsEntitiesDescription](docs/VetricTwitterTopSearchResponseTweetsInnerTweetUserDetailsEntitiesDescription.md)
 - [Wallet](docs/Wallet.md)
 - [WalletDetails](docs/WalletDetails.md)
 - [WalletType](docs/WalletType.md)
 - [WalletWithBalance](docs/WalletWithBalance.md)
 - [Web7Balance](docs/Web7Balance.md)
 - [Web7BalanceClaims](docs/Web7BalanceClaims.md)
 - [Web7BalanceEscrow](docs/Web7BalanceEscrow.md)
 - [Web7BalanceNative](docs/Web7BalanceNative.md)
 - [Web7BalanceOnchain](docs/Web7BalanceOnchain.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKeyAuth"></a>
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: skyfire-api-key
- **Location**: HTTP header


## Author

support@skyfire.xyz


